<?php

require("Configuration.php");

/**
 * Decorator adding type checks to a Configuration object.
 *
 * @author Daniel J. Lauk <daniel.lauk@psi.ch>
 */
class TypeCheckingConfiguration implements Configuration {

    private $config;

    private function assertTypeBoolean($val) {
        if (!is_bool($val))
            throw new RuntimeException('Not a boolean: ' . print_r($val, true));
    }

    private function assertTypeInteger($val) {
        if (!is_int($val))
            throw new RuntimeException('Not an integer: ' . print_r($val, true));
    }

    private function assertTypeString($val) {
        if (!is_string($val))
            throw new RuntimeException('Not a string: ' . print_r($val, true));
    }

    public function __construct(Configuration $configuration) {
        $this->config = $configuration;
    }

    public function getConfiguredSettings() {
        return $this->config->getConfiguredSettings();
    }

    public function getString($key) {
        $val = $this->config->getString($key);
        $this->assertTypeString($val);
        return $val;
    }

    public function getStringOrDefault($key, $default) {
        $val = $this->config->getStringOrDefault($key, $default);
        $this->assertTypeString($val);
        return $val;
    }

    public function getInteger($key) {
        $val = $this->config->getInteger($key);
        $this->assertTypeInteger($val);
        return $val;
    }

    public function getIntegerOrDefault($key, $default) {
        $val = $this->config->getIntegerOrDefault($key, $default);
        $this->assertTypeInteger($val);
        return $val;
    }

    public function getBoolean($key) {
        $val = $this->config->getBoolean($key);
        $this->assertTypeBoolean($val);
        return $val;
    }

    public function getBooleanOrDefault($key, $default) {
        $val = $this->config->getBooleanOrDefault($key, $default);
        $this->assertTypeBoolean($val);
        return $val;
    }
}

?>
